pub struct SearchKey { /* private fields */ }Expand description
Snapshot of every input that affects search results (not replacement). Used to skip scheduling debounced searches when the inputs haven’t changed since we last scheduled — cursor movements and idempotent toggles don’t need to re-run a search.
Deliberately excludes replacement_text (only affects preview) and
interpret_escape_sequences (only affects replacement interpretation).