EditorOpenConfig

Struct EditorOpenConfig 

pub struct EditorOpenConfig {
    pub command: Option<String>,
    pub exit: bool,
}

Fields

command: Option<String>

The command used when pressing e on the search results page. Two variables are available: %file, which will be replaced with the file path of the search result, and %line, which will be replaced with the line number of the result. For example:

[editor_open]
command = "vi %file +%line"

If not set explicitly, scooter will attempt to use the editor set by the $EDITOR environment variable.

This can be overridden using the --editor-command flag, for example: scooter --editor-command "vi %file +%line".

exit: bool

Whether to exit scooter after running the command defined by editor_open.command. Defaults to false.