pub struct KeysSearch {
pub toggle_preview_wrapping: Keys,
pub toggle_hidden_files: Keys,
pub toggle_multiline: Keys,
pub toggle_interpret_escape_sequences: Keys,
pub fields: KeysSearchFocusFields,
pub results: KeysSearchFocusResults,
}Fields
toggle_preview_wrapping: KeysToggle wrapping of lines that don’t fit within the width of the preview
Toggle inclusion of hidden files and directories, such as those whose name starts with a dot (.)
toggle_multiline: KeysToggle multiline search mode, which allows patterns to match across line boundaries
toggle_interpret_escape_sequences: KeysToggle interpretation of escape sequences in replacement text (\n becomes newline, \t becomes tab, \ becomes backslash)
fields: KeysSearchFocusFieldsCommands available on the search screen, when the search fields are focussed
results: KeysSearchFocusResultsCommands available on the search screen, when the search results are focussed