pub struct PreviewConfig {
pub syntax_highlighting: bool,
pub syntax_highlighting_theme: Theme,
pub wrap_text: bool,
}Fields
syntax_highlighting: boolWhether to apply syntax highlighting to the preview. Defaults to true.
syntax_highlighting_theme: ThemeThe theme to use when syntax highlighting is enabled.
The default is "base16-eighties.dark". Other built-in options are
"base16-mocha.dark", "base16-ocean.dark", "base16-ocean.light", "InspiredGitHub", "Solarized (dark)" and "Solarized (light)".
You can use other themes by adding .tmTheme files to <scooter-config-dir>/themes and then specifying their name here.
By default, <scooter-config-dir> is ~/.config/scooter/ on Linux or macOS, or %AppData%\scooter\ on Windows, and can be overridden with the --config-dir flag.
For instance, to use Catppuccin Macchiato (from here), on Linux or macOS run:
wget -P ~/.config/scooter/themes https://github.com/catppuccin/bat/raw/main/themes/Catppuccin%20Macchiato.tmThemeand then set syntax_highlighting_theme = "Catppuccin Macchiato".
wrap_text: boolWrap text onto the next line if it is wider than the preview window. Defaults to false. (Can be toggled in the UI using ctrl+l.)