Module replace

Module replace 

Structs

PerformingReplacementState
ReplaceState
ReplaceStats

Enums

ReplaceResult

Functions

add_replacement
add_replacement_with_haystack
calculate_statistics
interpret_escapes
Interpret escape sequences in replacement text.
perform_replacement
replace_all_if_match
Calculate replacement text for a line containing matches.
replace_all_in_file
Performs search and replace operations in a file
replace_in_file
NOTE: this should only be called with search results from the same file
replacement_for_match
Calculate replacement text for a specific matched substring.
replacement_for_match_in_haystack
Calculate replacement text for a specific match within a larger haystack.
spawn_replace_included
split_results