FileSearcher

Struct FileSearcher 

pub struct FileSearcher { /* private fields */ }

Implementations

Source

impl FileSearcher

pub fn search(&self) -> &SearchType

pub fn replace(&self) -> &String

pub fn multiline(&self) -> bool

Source

impl FileSearcher

pub fn new( search_config: ParsedSearchConfig, dir_config: ParsedDirConfig, ) -> Self

pub fn walk_files<F>(&self, cancelled: Option<&AtomicBool>, file_handler: F)
where F: FnMut() -> Box<dyn FnMut(Vec<SearchResult>) -> WalkState + Send> + Send,

Walks through files in the configured directory and processes matches.

This method traverses the filesystem starting from the root_dir specified in the FileSearcher, respecting the configured overrides (include/exclude patterns) and hidden file settings. It uses parallel processing when possible for better performance.

Parameters
  • cancelled - An optional atomic boolean that can be used to signal cancellation from another thread. If this is set to true during execution, the search will stop as soon as possible.

  • file_handler - A closure that returns a FileVisitor. The returned FileVisitor is a function that processes search results for each file with matches.

Example
use std::{
    sync::{atomic::AtomicBool, mpsc},
    path::PathBuf,
};
use regex::Regex;
use ignore::{WalkState, overrides::Override};
use scooter_core::search::{FileSearcher, ParsedSearchConfig, ParsedDirConfig, SearchResult, SearchType};

let search_config = ParsedSearchConfig {
    search: SearchType::Pattern(Regex::new("pattern").unwrap()),
    replace: "replacement".to_string(),
    multiline: false,
};
let dir_config = ParsedDirConfig {
    overrides: Override::empty(),
    root_dir: PathBuf::from("."),
    include_hidden: false,
};
let searcher = FileSearcher::new(search_config, dir_config);
let cancelled = AtomicBool::new(false);

searcher.walk_files(Some(&cancelled), move || {
    Box::new(move |results| {
        if process(results).is_err() {
            WalkState::Quit
        } else {
            WalkState::Continue
        }
    })
});

fn process(results: Vec<SearchResult>) -> anyhow::Result<()> {
    println!("{results:?}");
    Ok(())
}
pub fn walk_files_and_replace(&self, cancelled: Option<&AtomicBool>) -> usize

Walks through files in the configured directory and replaces matches.

This method traverses the filesystem starting from the root_dir specified in the FileSearcher, respecting the configured overrides (include/exclude patterns) and hidden file settings. It replaces all matches of the search pattern with the replacement text in each file.

Parameters
  • cancelled - An optional atomic boolean that can be used to signal cancellation from another thread. If this is set to true during execution, the search will stop as soon as possible.
Returns

The number of files that had replacements performed in them.