Structs
Enums
Functions
- add_
replacement - add_
replacement_ with_ haystack - calculate_
statistics - interpret_
escapes - Interpret escape sequences in replacement text.
- perform_
replacement - replace_
all_ if_ match - Calculate replacement text for a line containing matches.
- replace_
all_ in_ file - Performs search and replace operations in a file
- replace_
in_ file - NOTE: this should only be called with search results from the same file
- replacement_
for_ match - Calculate replacement text for a specific matched substring.
- replacement_
for_ match_ in_ haystack - Calculate replacement text for a specific match within a larger haystack.
- spawn_
replace_ included - split_
results